@@ -27,7 +27,6 @@ DEALINGS IN THE SOFTWARE.
 
 # include <QtCore/QDebug>
 # include <QRegularExpression>
-# include <QRegularExpressionValidator>
 # include <QDBusMessage>
 # include <QDBusConnection>
 # include <QDBusInterface>
@@ -41,18 +40,17 @@ DEALINGS IN THE SOFTWARE.
 # include <QProcessEnvironment>
 
 # include "./vpn_ed.h"
-# include "./code/provisioning/prov_ed.h"	// use ValidatingDialog from ProvEd
 # include "../resource.h"
 # include "./code/trstring/tr_strings.h"
+# include "./code/shared/shared.h"
    
 //
-// This class is derived from the ProvisioningEditor class, and in fact
-// it uses validating code from there.  There are a few improvements
+// This class is derived from the ProvisioningEditor class,  There are a few improvements
 // mainly in more efficient packaging of the text data into each QAction.
 //
 // In this class:
 // QAction->text() contains the key for the Connman config file and display
-// text for the menus.
+// text for the menus. NOTE: This text cannot be translated.  
 // QAction->toolTip() contains the text displayed in dialogs
 //
 // I've also removed the template section since the new group_provider actions
@@ -398,28 +396,28 @@ void VPN_Editor::inputValidated(QAction* act, QString key)
   if (key.isEmpty() ) key = act->text();
   
   // create the dialog
-  ValidatingDialog* vd = new ValidatingDialog(this);
+  shared::ValidatingDialog* vd = new shared::ValidatingDialog(this);
   
   // create some prompts and set validator
-  if (key == "Host") {vd->setLabel(tr("VPN server IP address (ex: 1.2.3.4)")), vd->setValidator(CMST::ProvEd_Vd_46, false);}
+  if (key == "Host") {vd->setLabel(tr("VPN server IP address (ex: 1.2.3.4)")), vd->setValidator(CMST::ValDialog_46, false);}
   else vd->setLabel(act->toolTip() );
   
-  if (act == ui.actionPPPD_EchoFailure) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-	if (act == ui.actionPPPD_EchoInterval) vd->setValidator(CMST::ProvEd_Vd_Int, false);	  
-  if (act == ui.actionL2TP_BPS) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_TXBPS) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_RXBPS) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_TunnelRWS) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_RedialTImeout) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_MaxRedials) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionL2TP_ListenAddr) vd->setValidator(CMST::ProvEd_Vd_46, false);
-  if (act == ui.actionVPNC_LocalPort) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionVPNC_CiscoPort) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionVPNC_DPDTimeout) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionOpenVPN_MTU) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionOpenVPN_Port) vd->setValidator(CMST::ProvEd_Vd_Int, false);
-  if (act == ui.actionOpenConnect_ServerCert) vd->setValidator(CMST:: ProvEd_Vd_Hex, false);
-  if (act == ui.actionOpenConnect_VPNHost) vd->setValidator(CMST::ProvEd_Vd_46, false);
+  if (act == ui.actionPPPD_EchoFailure) vd->setValidator(CMST::ValDialog_Int, false);
+	if (act == ui.actionPPPD_EchoInterval) vd->setValidator(CMST::ValDialog_Int, false);	  
+  if (act == ui.actionL2TP_BPS) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_TXBPS) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_RXBPS) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_TunnelRWS) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_RedialTImeout) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_MaxRedials) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionL2TP_ListenAddr) vd->setValidator(CMST::ValDialog_46, false);
+  if (act == ui.actionVPNC_LocalPort) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionVPNC_CiscoPort) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionVPNC_DPDTimeout) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionOpenVPN_MTU) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionOpenVPN_Port) vd->setValidator(CMST::ValDialog_Int, false);
+  if (act == ui.actionOpenConnect_ServerCert) vd->setValidator(CMST:: ValDialog_Hex, false);
+  if (act == ui.actionOpenConnect_VPNHost) vd->setValidator(CMST::ValDialog_46, false);
 
   // if accepted put an entry in the textedit
   if (vd->exec() == QDialog::Accepted) {
@@ -463,17 +461,17 @@ void VPN_Editor::inputComboBox(QAction* act)
   if (act == ui.actionOpenVPN_CompLZO) sl << "adaptive" << "yes" << "no";
   if (act == ui.actionOpenVPN_RemoteCertTls) sl << "client" << "server";
   
+  QStringList sl_tr = TranslateStrings::cmtr_sl(sl);
   QString item = QInputDialog::getItem(this,
     tr("%1 - Item Input").arg(TranslateStrings::cmtr("cmst")),
     str,
-    sl,
+    sl_tr,
     0,
     false,
     &ok);
     
   key.append(" = %1\n");
-  if (ok) ui.plainTextEdit_main->insertPlainText(key.arg(item));
-  
+  if (ok) ui.plainTextEdit_main->insertPlainText(key.arg(sl.at(sl_tr.indexOf(QRegularExpression(item)))) );   
   return;
 }
 
